@@ -3,9 +3,8 @@
 package.cpath = ".libs/liblua-?.so;" .. package.cpath
 
 require "lunit"
-lunit.import "all"
 
-is = assert_equal
+is = lunit.assert_equal
 
 function read_file (filename)
     local fh = io.open(filename, "rb")
@@ -27,4 +26,4 @@ function bytes_to_hex (s)
     return hex
 end
 
--- vim:ts=4 sw=4 expandtab filetype=lua
+-- vi:ts=4 sw=4 expandtab
